Welcome to Pantea's documentation!
======================================


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   usage
   theory
   examples
   modules
   contributing
   authors


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
